==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/ImageSourceBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ImageSourceBuilder extends io.fabric8.openshift.api.model.ImageSourceFluentImpl<io.fabric8.openshift.api.model.ImageSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ImageSource,io.fabric8.openshift.api.model.ImageSourceBuilder>{
  public ImageSourceBuilder() {
    this(false);
  }
  public ImageSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new ImageSource(), validationEnabled);
  }
  public ImageSourceBuilder(io.fabric8.openshift.api.model.ImageSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageSourceBuilder(io.fabric8.openshift.api.model.ImageSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ImageSource(), validationEnabled);
  }
  public ImageSourceBuilder(io.fabric8.openshift.api.model.ImageSourceFluent<?> fluent,io.fabric8.openshift.api.model.ImageSource instance) {
    this(fluent, instance, false);
  }
  public ImageSourceBuilder(io.fabric8.openshift.api.model.ImageSourceFluent<?> fluent,io.fabric8.openshift.api.model.ImageSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAs(instance.getAs()); 
    fluent.withFrom(instance.getFrom()); 
    fluent.withPaths(instance.getPaths()); 
    fluent.withPullSecret(instance.getPullSecret()); 
    this.validationEnabled = validationEnabled; 
  }
  public ImageSourceBuilder(io.fabric8.openshift.api.model.ImageSource instance) {
    this(instance,false);
  }
  public ImageSourceBuilder(io.fabric8.openshift.api.model.ImageSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAs(instance.getAs()); 
    this.withFrom(instance.getFrom()); 
    this.withPaths(instance.getPaths()); 
    this.withPullSecret(instance.getPullSecret()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ImageSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ImageSource build() {
    ImageSource buildable = new ImageSource(fluent.getAs(),fluent.getFrom(),fluent.getPaths(),fluent.getPullSecret());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageSourceBuilder that = (ImageSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/ImageSourceBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ImageSourceBuilder extends io.fabric8.openshift.api.model.ImageSourceFluentImpl<io.fabric8.openshift.api.model.ImageSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ImageSource,io.fabric8.openshift.api.model.ImageSourceBuilder>{
  public ImageSourceBuilder() {
    this(false);
  }
  public ImageSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new ImageSource(), validationEnabled);
  }
  public ImageSourceBuilder(io.fabric8.openshift.api.model.ImageSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageSourceBuilder(io.fabric8.openshift.api.model.ImageSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ImageSource(), validationEnabled);
  }
  public ImageSourceBuilder(io.fabric8.openshift.api.model.ImageSourceFluent<?> fluent,io.fabric8.openshift.api.model.ImageSource instance) {
    this(fluent, instance, false);
  }
  public ImageSourceBuilder(io.fabric8.openshift.api.model.ImageSourceFluent<?> fluent,io.fabric8.openshift.api.model.ImageSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAs(instance.getAs()); 
    fluent.withFrom(instance.getFrom()); 
    fluent.withPaths(instance.getPaths()); 
    fluent.withPullSecret(instance.getPullSecret()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ImageSourceBuilder(io.fabric8.openshift.api.model.ImageSource instance) {
    this(instance,false);
  }
  public ImageSourceBuilder(io.fabric8.openshift.api.model.ImageSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAs(instance.getAs()); 
    this.withFrom(instance.getFrom()); 
    this.withPaths(instance.getPaths()); 
    this.withPullSecret(instance.getPullSecret()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ImageSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ImageSource build() {
    ImageSource buildable = new ImageSource(fluent.getAs(),fluent.getFrom(),fluent.getPaths(),fluent.getPullSecret());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageSourceBuilder that = (ImageSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
